==> deepin-polkit-agent-5.4.16-1.src.tar.gz: dde-polkit-agent-5.4.16/translations/dde-polkit-agent_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="96"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>El dit s&apos;ha mogut massa de pressa. Si us plau, no l&apos;alceu fins que s&apos;avisi.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Verification failed, two chances left</source>
        <translation>Ha fallat la verificació. Us resten 2 intents.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="118"/>
        <location filename="../AuthDialog.cpp" line="303"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="213"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>Cal que canvieu la contrasenya immediatament (ha caducat).</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="278"/>
        <source>Wrong password, only one chance left</source>
        <translation>Contrasenya incorrecta. Només us resta un intent.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="281"/>
        <source>Wrong password, two chances left</source>
        <translation>Contrasenya incorrecta. Us queden dos intents.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="285"/>
        <source>Wrong password</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="302"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
</context>
</TS>

==> deepin-polkit-agent-5.4.17-1.src.tar.gz: dde-polkit-agent-5.4.17/translations/dde-polkit-agent_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>El dit s&apos;ha mogut massa de pressa. Si us plau, no l&apos;alceu fins que s&apos;avisi.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="100"/>
        <source>Verification failed, two chances left</source>
        <translation>Ha fallat la verificació. Us resten 2 intents.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="120"/>
        <location filename="../AuthDialog.cpp" line="326"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="227"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>Cal que canvieu la contrasenya immediatament (ha caducat).</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="299"/>
        <source>Locked, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password, only one chance left</source>
        <translation type="vanished">Contrasenya incorrecta. Només us resta un intent.</translation>
    </message>
    <message>
        <source>Wrong password, two chances left</source>
        <translation type="vanished">Contrasenya incorrecta. Us queden dos intents.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="301"/>
        <source>Wrong password</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="325"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
</context>
</TS>
